@@ -7,6 +7,7 @@ import sys
 import subprocess
 import unittest
 import tempfile
+import datetime
 
 import fiona
 from fiona.collection import Collection, supported_drivers
@@ -137,7 +138,7 @@ class ReadingTest(unittest.TestCase):
     def test_schema(self):
         s = self.c.schema['properties']
         self.failUnlessEqual(s['CAT'], "float:16")
-        self.failUnlessEqual(s['FIPS_CNTRY'], "str")
+        self.failUnlessEqual(s['FIPS_CNTRY'], "str:80")
 
     def test_closed_schema(self):
         # Schema is lazy too, never computed in this case. TODO?
@@ -246,6 +247,16 @@ class FilterReadingTest(unittest.TestCase):
         f = results[0]
         self.failUnlessEqual(f['id'], "0")
         self.failUnlessEqual(f['properties']['FIPS_CNTRY'], 'UK')
+    def test_filter_reset(self):
+        results = list(self.c.filter(bbox=(-15.0, 55.0, 15.0, 65.0)))
+        self.failUnlessEqual(len(results), 41)
+        results = list(self.c.filter())
+        self.failUnlessEqual(len(results), 48)
+        
+    def test_filter_mask(self):
+        mask = {'type': 'Polygon', 'coordinates': (((-2.0, 60.0), (-2.0, 60.0), (0.0, 61.0), (0.0, 60.0), (-2.0, 60.0)),)}
+        results = list(self.c.filter(mask=mask))
+        self.failUnlessEqual(len(results), 1)
 
 class UnsupportedDriverTest(unittest.TestCase):
     
@@ -288,8 +299,9 @@ class PointWritingTest(unittest.TestCase):
 
     def setUp(self):
         self.tempdir = tempfile.mkdtemp()
+        self.filename = os.path.join(self.tempdir, "point_writing_test.shp")
         self.sink = fiona.open(
-            os.path.join(self.tempdir, "point_writing_test.shp"),
+            self.filename,
             "w",
             driver="ESRI Shapefile",
             schema={
@@ -316,6 +328,12 @@ class PointWritingTest(unittest.TestCase):
         self.sink.writerecords([f])
         self.failUnlessEqual(len(self.sink), 1)
         self.failUnlessEqual(self.sink.bounds, (0.0, 0.1, 0.0, 0.1))
+        self.sink.close()
+        info = subprocess.check_output(
+            ["ogrinfo", self.filename, "point_writing_test"])
+        self.assert_(
+            'date (Date) = 2012/01/29' in info.decode('utf-8'),
+            info)
 
     def test_write_two(self):
         self.failUnlessEqual(len(self.sink), 0)
@@ -529,3 +547,39 @@ class GeoJSONCRSWritingTest(unittest.TestCase):
             'GEOGCS["WGS 84' in info.decode('utf-8'),
             info)
 
+class DateTimeTest(unittest.TestCase):
+    def setUp(self):
+        self.tempdir = tempfile.mkdtemp()
+
+    def test_date(self):
+        self.sink = fiona.open(
+            os.path.join(self.tempdir, "date_test.shp"),
+            "w",
+            driver="ESRI Shapefile",
+            schema={
+                'geometry': 'Point',
+                'properties': [('id', 'int'), ('date', 'date')]},
+            crs={'init': "epsg:4326", 'no_defs': True})
+
+        recs = [{
+            'geometry': {'type': 'Point',
+                         'coordinates': (7.0, 50.0)},
+            'properties': {'id': 1, 'date': '2013-02-25'}
+        }, {
+            'geometry': {'type': 'Point',
+                         'coordinates': (7.0, 50.2)},
+            'properties': {'id': 1, 'date': datetime.date(2014, 2, 3)}
+        }]
+        self.sink.writerecords(recs)
+        self.sink.close()
+        self.failUnlessEqual(len(self.sink), 2)
+
+        c = fiona.open(os.path.join(self.tempdir, "date_test.shp"), "r")
+        self.failUnlessEqual(len(c), 2)
+
+        rf1, rf2 = list(c)
+        self.failUnlessEqual(rf1['properties']['date'], '2013-02-25')
+        self.failUnlessEqual(rf2['properties']['date'], '2014-02-03')
+
+    def tearDown(self):
+        shutil.rmtree(self.tempdir)
